Merge 5696a5b6fa7de45aca52123c1db6e18140622014 on remote branch
Change-Id: I1886343b4c0ac36107176982fa471de51922a7a2
diff --git a/sound_trigger_platform.c b/sound_trigger_platform.c
index 18e59e2..8441659 100644
--- a/sound_trigger_platform.c
+++ b/sound_trigger_platform.c
@@ -64,6 +64,7 @@
#include <errno.h>
#include <fcntl.h>
#include <sys/ioctl.h>
+#include <sound/asound.h>
#include <sound/msmcal-hwdep.h>
#include <linux/msm_audio_calibration.h> /* for AUDIO_CORE_METAINFO_CAL_TYPE; audio_cal_info_metainfo */
#include <sound/lsm_params.h>
diff --git a/st_hw_session_lsm.c b/st_hw_session_lsm.c
index 9b41c03..1407618 100644
--- a/st_hw_session_lsm.c
+++ b/st_hw_session_lsm.c
@@ -46,6 +46,7 @@
#include <cutils/atomic.h>
#include <cutils/trace.h>
#include <system/thread_defs.h>
+#include <sound/asound.h>
#include <stdarg.h>
#include <unistd.h>
diff --git a/st_session.c b/st_session.c
index a32b71d..156bfb9 100644
--- a/st_session.c
+++ b/st_session.c
@@ -203,7 +203,6 @@
ev.payload.detected.detect_status = 3;
DISPATCH_EVENT(st_ses, ev, status);
- break;
}
if (!lock_status)
@@ -5189,17 +5188,10 @@
st_ses->sm_handle);
/*
* Device switch will not wait for buffering to finish. It will instead
* interrupt and stop the buffering and transition to the loaded state.
* The loaded state will then take care of the device switch.
*/
hw_ses->fptrs->stop_buffering(hw_ses);
- status = stop_session(st_ses, hw_ses, false);
- if (status && !st_ses->stdev->ssr_offline_received) {
- ALOGE("%s:[%d] failed to stop session, err %d", __func__,
- st_ses->sm_handle, status);
- break;
- }
- STATE_TRANSITION(st_ses, loaded_state_fn);
+ STATE_TRANSITION(st_ses, active_state_fn);
DISPATCH_EVENT(st_ses, *ev, status);
/*
@@ -5214,7 +5206,7 @@
ST_SES_EV_DEFERRED_STOP);
stc_ses->pending_stop = false;
}
- st_ses->det_stc_ses->state = ST_STATE_LOADED;
+ st_ses->det_stc_ses->state = ST_STATE_ACTIVE;
break;
case ST_SES_EV_START:
@@ -5189,17 +5188,10 @@
/*
* Device switch will not wait for buffering to finish. It will instead
- * interrupt and stop the buffering and transition to the loaded state.
- * The loaded state will then take care of the device switch.
+ * interrupt and stop the buffering and transition to the active state.
*/
hw_ses->fptrs->stop_buffering(hw_ses);